Future Roadmap
--------------

Wishlist for 1.0 (anytime in year 2017)

*  Test against several environments and deployment modes automatically (rhel?/ubuntu/debian X pip/git/virtualenv X python2.{5,6,7})
*  Add support for SLURM - need at least 3 clusters traces to get things started - and human help
*  Add support for LSF - need at least 3 clusters traces to get things started - and human help
*  Dissociate presentation from calculation (currently it is tic-tac in a lockstep)
*  Ensure that runs on 1000+ node clusters result in a functional tool without major hurdles
*  Improve troubleshooting by better reporting and do best-effort approach when input is clunky
*  Export state in JSON format online
*  Provide EasyBuild easyconfig so that delivery is possible in that way, too
